==> apache-storm-1.2.1-src.zip: apache-storm-1.2.1/external/storm-kinesis/src/main/java/org/apache/storm/kinesis/spout/FailedMessageRetryHandler.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.storm.kinesis.spout;

import java.io.Serializable;

public interface FailedMessageRetryHandler extends Serializable {
    /**
     * message with messageId failed in the spout
     * @param messageId
     * @return true if this failed message was scheduled to be retried, false otherwise
     */
    boolean failed (KinesisMessageId messageId);

    /**
     * message with messageId succeeded/acked in the spout
     * @param messageId
     */
    void acked (KinesisMessageId messageId);

    /**
     * Get the next failed message's id to retry if any, null otherwise
     * @return messageId
     */
    KinesisMessageId getNextFailedMessageToRetry ();

    /**
     * message with messageId returned by last call to getNextFailedMessageToRetry was emitted/retried by the spout
     * @param messageId
     */
    void failedMessageEmitted (KinesisMessageId messageId);
}

==> apache-storm-2.3.0-src.zip: apache-storm-2.3.0/external/storm-kinesis/src/main/java/org/apache/storm/kinesis/spout/FailedMessageRetryHandler.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.storm.kinesis.spout;

import java.io.Serializable;

public interface FailedMessageRetryHandler extends Serializable {
    /**
     * message with messageId failed in the spout.
     * @param messageId the message id
     * @return true if this failed message was scheduled to be retried, false otherwise
     */
    boolean failed(KinesisMessageId messageId);

    /**
     * message with messageId succeeded/acked in the spout.
     * @param messageId the message id
     */
    void acked(KinesisMessageId messageId);

    /**
     * Get the next failed message's id to retry if any, null otherwise.
     * @return messageId
     */
    KinesisMessageId getNextFailedMessageToRetry();

    /**
     * message with messageId returned by last call to getNextFailedMessageToRetry was emitted/retried by the spout.
     * @param messageId the message id
     */
    void failedMessageEmitted(KinesisMessageId messageId);
}
